[][src]Enum abortable_parser::Result

pub enum Result<I: InputIter, O> {
    Complete(I, O),
    Incomplete(I),
    Fail(Error<I>),
    Abort(Error<I>),
}

The result of a parsing attempt.

Variants

Complete(I, O)

Complete represents a successful match.

Incomplete(I)

Incomplete indicates input ended before a match could be completed. It contains the offset at which the input ended before a match could be completed.

Fail(Error<I>)

Fail represents a failed match.

Abort(Error<I>)

Abort represents a match failure that the parser cannot recover from.

Methods

impl<I: InputIter, O> Result<I, O>[src]

pub fn is_complete(&self) -> bool[src]

Returns true if the Result is Complete.

pub fn is_incomplete(&self) -> bool[src]

Returns true if the Result is Incomoplete.

pub fn is_fail(&self) -> bool[src]

Returns true if the Result is Fail.

pub fn is_abort(&self) -> bool[src]

Returns true if the Result is Abort.